==> throwing-jdbc-4.0-0.7.9-20150128.172147-4-sources.jar: org/melati/poem/dbms/test/sql/ThrowingResultSetMetaData.java <==
/*
 * $Source$
 * $Revision$
 *
 * Copyright (C) 2007 Tim Pizey
 *
 * Part of Melati (http://melati.org), a framework for the rapid
 * development of clean, maintainable web applications.
 *
 * Melati is free software; Permission is granted to copy, distribute
 * and/or modify this software under the terms either:
 *
 * a) the GNU General Public License as published by the Free Software
 *    Foundation; either version 2 of the License, or (at your option)
 *    any later version,
 *
 *    or
 *
 * b) any version of the Melati Software License, as published
 *    at http://melati.org
 *
 * You should have received a copy of the GNU General Public License and
 * the Melati Software License along with this program;
 * if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA to obtain the
 * GNU General Public License and visit http://melati.org to obtain the
 * Melati Software License.
 *
 * Feel free to contact the Developers of Melati (http://melati.org),
 * if you would like to work out a different arrangement than the options
 * outlined here.  It is our intention to allow Melati to be used by as
 * wide an audience as possible.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * Contact details for copyright holder:
 *
 *     Tim Pizey <timp At paneris.org>
 *     http://paneris.org/~timp
 */
package org.melati.poem.dbms.test.sql;

import java.sql.ResultSetMetaData;


/**
 * A {@link ResultSetMetaData} decorated to throw an {@SQLException} on command.
 * 
 * @author timp
 * @since 12 Feb 2007
 *
 */
public class ThrowingResultSetMetaData 
    extends ThrowingResultSetMetaDataVariant 
    implements ResultSetMetaData {
  
  /**
   * Constructor.
   * @param rsmd to decorate
   */
  public ThrowingResultSetMetaData(ResultSetMetaData rsmd) {
    this.it = rsmd;
  }
  
}

==> throwing-jdbc-4.1-0.7.9-sources.jar: org/melati/poem/dbms/test/sql/ThrowingResultSetMetaData.java <==
/*
 * $Source$
 * $Revision$
 *
 * Copyright (C) 2007 Tim Pizey
 *
 * Part of Melati (http://melati.org), a framework for the rapid
 * development of clean, maintainable web applications.
 *
 * Melati is free software; Permission is granted to copy, distribute
 * and/or modify this software under the terms either:
 *
 * a) the GNU General Public License as published by the Free Software
 *    Foundation; either version 2 of the License, or (at your option)
 *    any later version,
 *
 *    or
 *
 * b) any version of the Melati Software License, as published
 *    at http://melati.org
 *
 * You should have received a copy of the GNU General Public License and
 * the Melati Software License along with this program;
 * if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA to obtain the
 * GNU General Public License and visit http://melati.org to obtain the
 * Melati Software License.
 *
 * Feel free to contact the Developers of Melati (http://melati.org),
 * if you would like to work out a different arrangement than the options
 * outlined here.  It is our intention to allow Melati to be used by as
 * wide an audience as possible.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * Contact details for copyright holder:
 *
 *     Tim Pizey <timp At paneris.org>
 *     http://paneris.org/~timp
 */
package org.melati.poem.dbms.test.sql;

import java.sql.ResultSetMetaData;


/**
 * A {@link ResultSetMetaData} decorated to throw an SQLException on command.
 * 
 * @author timp
 * @since 12 Feb 2007
 *
 */
public class ThrowingResultSetMetaData 
    extends ThrowingResultSetMetaDataVariant 
    implements ResultSetMetaData {
  
  /**
   * Constructor.
   * @param rsmd to decorate
   */
  public ThrowingResultSetMetaData(ResultSetMetaData rsmd) {
    this.it = rsmd;
  }
  
}
